@@ -5,7 +5,7 @@ use warnings;
 package Mite::Miteception;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.007001';
+our $VERSION   = '0.007002';
 
 use Import::Into;
 use Mite::Shim ();
@@ -25,7 +25,7 @@ sub import {
 
 	my ( $caller, $file ) = caller;
 
-	if ( $ENV{MITE_LIMITED_PARSING} ) {
+	if ( $ENV{MITE_COMPILE_SELF} ) {
 		require Mite::Project;
 		Mite::Project->default->inject_mite_functions(
 			 package     => $caller,
