@@ -6,7 +6,7 @@ package Mite::Project;
 use Mite::Miteception -all;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.007001';
+our $VERSION   = '0.007002';
 
 has sources =>
   is            => ro,
@@ -23,11 +23,6 @@ has config =>
       return $config;
   };
 
-has _limited_parsing =>
-  is            => rw,
-  isa           => Bool,
-  default       => false;
-
 has _module_fakeout_namespace =>
   is            => rw,
   isa           => Str | Undef;
@@ -37,8 +32,6 @@ has debug =>
   isa           => Bool,
   default       => false;
 
-##-
-
 use Mite::Source;
 use Mite::Class;
 
@@ -113,7 +106,7 @@ sub inject_mite_functions {
     warn "Gather: $package\n" if $self->debug;
 
     $source //= $self->source_for(
-        Path::Tiny::path( $ENV{MITE_LIMITED_PARSING} // $file )
+        Path::Tiny::path( $ENV{MITE_COMPILE_SELF} // $file )
     );
     $pkg    //= $source->class_for(
         $package,
@@ -282,19 +275,16 @@ sub _load_file {
 
     $file = Path::Tiny::path($file);
 
-    if ( $self->_limited_parsing ) {
-        my $code = $file->slurp;
-        my ( $head, $tail ) = split '##-', $code;
+    if ( defined $self->_module_fakeout_namespace ) {
+        my $ns = $self->_module_fakeout_namespace;
 
-        if ( defined $self->_module_fakeout_namespace ) {
-            my $ns = $self->_module_fakeout_namespace;
-            $head =~ s/package /package $ns\::/;
-        }
+        my $code = $file->slurp;
+        $code =~ s/package /package $ns\::/;
 
         do {
             local $@;
-            local $ENV{MITE_LIMITED_PARSING} = "$file";
-            eval("$head; 1") or do die($@);
+            local $ENV{MITE_COMPILE_SELF} = "$file";
+            eval("$code; 1") or do die($@);
         };
 
         return;
